@@ -320,7 +320,8 @@ def create_mr_slots(sources, platforms, merge, model_slots):
         for name, commit in commits.items():
             repos[name].checkout_opts['commit'] = commit
         for name, mrs in merges.items():
-            repos[name].checkout_opts['merges'] = mrs
+            repos[name].checkout_opts['merges'] = (
+                repos[name].checkout_opts.get('merges', []) + mrs)
 
     requested_projects = sorted(project_sources.keys())
     ref_slot.metadata['ci_test'] = {
