@@ -503,6 +503,8 @@ string(REPLACE "$${NIGHTLY_BUILD_ROOT}" "$${CMAKE_CURRENT_LIST_DIR}"
                     args=['-k'],
                     make_cmd=make_cmd,
                     stderr=STDOUT,
+                    # if not in release builds (i.e. no_patch = False) allow missing artifacts
+                    relaxed_install=not self.slot.no_patch,
                     before=record_start):
                 summary_dir = self._summaryDir(proj)
                 ensureDirs([summary_dir])
