@@ -128,7 +128,7 @@ class Script(BaseScript):
 
         self.log.debug('looking for files matching /%s/', include.pattern)
         from os.path import join, relpath, dirname, exists
-        from zipfile import ZipFile
+        from zipfile import ZipFile, ZIP_DEFLATED
         proj_root = root or self._buildDir(proj)
         zip_name = self._summaryDir(target_dir, proj) + '.zip'
 
@@ -144,7 +144,7 @@ class Script(BaseScript):
         # FIXME: it should be better to use a temporary file
         ensureDirs(dirname(zip_name))
         zip_empty = True
-        with ZipFile(zip_name, 'w') as dest_zip:
+        with ZipFile(zip_name, mode='w', compression=ZIP_DEFLATED) as dest_zip:
             for src in all_requested_files():
                 try:
                     dest_zip.write(src, relpath(src, proj_root))
@@ -189,6 +189,7 @@ class Script(BaseScript):
 
             def before(proj):
                 '''callback used before testing a project'''
+                self.assert_not_aborted()
                 self.send({
                     'project': proj.name,
                     'started': datetime.now().isoformat()
@@ -225,7 +226,7 @@ class Script(BaseScript):
                             'flags: {0}'.format(' '.join(cpuinfo[0]['flags'])),
                         ]
                         write_json(annotations, annotations_json)
-                except Exception, x:  # ignore errors reading summary file
+                except Exception as x:  # ignore errors reading summary file
                     self.log.warning('failed to update annotations.json: %s',
                                      x)
 
