@@ -1339,23 +1339,33 @@ def compatible_lcg_external_files(ext_file_name):
     paths = [ext_file_name]
 
     # split the name in components
-    parts = re.match(r"^(.*/LCG_externals_)([^-]+)(-.*\.txt)$", ext_file_name)
+    parts = re.match(r"^(.*/LCG_externals_)([^-]+(?:-[^-]+){3})(\.txt)$",
+                     ext_file_name)
     if not parts:
         # no need to continue if we do not understand the filename
         return paths
-    head, arch, tail = parts.groups()
+    head, platform, tail = parts.groups()
+    _, os_id, comp, opt = platform.split('-')
 
     # this is a trick to promote "x86_64+avx2" to "x86_64_v3"
-    arch = requires(arch + "-...-").split("-", 1)[0]
+    arch = requires(platform).split("-", 1)[0]
 
-    if arch in ARCH_DEFS:
-        # if it's a known architecture we extend the list with the
-        # architectures we can use
-        archs = get_supported_archs(ARCH_DEFS[arch])
-        # list of externals files we could use
-        paths.extend("{}{}{}".format(head, arch, tail) for arch in archs)
+    # if it's a known architecture we extend the list with the
+    # architectures we can use
+    archs = get_supported_archs(
+        ARCH_DEFS[arch]) if arch in ARCH_DEFS else [arch]
 
-    # remove duplicates
+    comp_parts = comp.split("+")
+    comps = ["+".join(comp_parts[0:n]) for n in range(len(comp_parts), 0, -1)]
+
+    opt_parts = opt.split("+")
+    opts = ["+".join(opt_parts[0:n]) for n in range(len(opt_parts), 0, -1)]
+
+    # list of externals files we could use
+    paths.extend("{}{}-{}-{}-{}{}".format(head, arch, os_id, comp, opt, tail)
+                 for arch in archs for comp in comps for opt in opts)
+
+    # remove duplicates (preserving the order)
     unique = []
     for path in paths:
         if path not in unique:
