@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2014-2016 CERN                                                     #
+# (c) Copyright 2014-2022 CERN                                                #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -19,7 +19,9 @@ Created on Feb 27, 2014
 import os
 import re
 import logging
+import tempfile
 from string import Template
+from lbinstall.Installer import Installer
 try:
     from LbEnv.ProjectEnv.lookup import findProject, MissingProjectError
 except ImportError:
@@ -66,16 +68,16 @@ def cmpLCGVersion(x, y):
 
 
 def convertToLHCbClassicVersion(version):
-    ''' Convert a version of the type X.Y.X to vXrYpZ.
+    ''' Convert a version of the type X.Y[.Z[.T]] to vXrY[pZ[tT]].
     Leaves the other strings unaffected
     '''
 
     # Case when we specify the version as point separated numbers
     if re.match(r"^\d[\d.]*$", version):
         # this is a X.Y CMake style version, so we map it to vXr*
-        # - get the first 4 element max (we support vXrYpZgA)
+        # - get the first 4 element max (we support vXrYpZtT)
         parts = version.split(".")[:4]
-        return "".join(a + b for a, b in zip("vrpg", parts))
+        return "".join(a + b for a, b in zip("vrpt", parts))
 
     return version
 
@@ -126,6 +128,7 @@ class LHCbBaseRpmSpec(object):
         self._version = version
         self._lhcb_release_version = 0
         self._prodRPMReleaseDir = prodRPMReleaseDir
+        self._checkRelease = False
 
     def getSpec(self):
         """ Build the global spec file """
@@ -197,11 +200,42 @@ class LHCbBaseRpmSpec(object):
         """ Set the location for the RPM release directory """
         self._prodRPMReleaseDir = rpmRelDir
 
+    def setCheckRelease(self, checkRelease):
+        """ Set the flags enabling the check of the release number in the YUM repository """
+        self._checkRelease = checkRelease
+
+    def _getMatchingRPMFromRepo(self, name, version):
+        """ Looking up a package by name in the YUM repo"""
+        with tempfile.TemporaryDirectory() as siteroot:
+            return Installer(siteroot=siteroot).remoteFindPackage(
+                name, version=version)
+
     def _setNextReleaseNumberFromRepo(self):
         """ Checks the RPM release dir (see constructor for the class) to find the
         next release number for the package.
         """
         if self._lhcb_release_version <= 0:
+            if self._checkRelease:
+                projver = ".".join([
+                    str(n) for n in [
+                        self._lhcb_maj_version, self._lhcb_min_version, self.
+                        _lhcb_patch_version
+                    ]
+                ])
+                __log__.debug("Looking for releases of %s / %s" %
+                              (self.getRPMName(norpmver=True), projver))
+                packages = self._getMatchingRPMFromRepo(
+                    self.getRPMName(norpmver=True), projver)
+                __log__.debug("Found package %s" % packages)
+                if not packages:
+                    self._lhcb_release_version = 1
+                else:
+                    prev_releases = [int(p.release) for p in packages]
+                    __log__.debug("Previous versions releases" % prev_releases)
+                    nextver = max(prev_releases) + 1
+                    self._lhcb_release_version = nextver
+                    __log__.warning("Release number set to %s" %
+                                    self._lhcb_release_version)
             if self._prodRPMReleaseDir != None and os.path.exists(
                     self._prodRPMReleaseDir):
                 __log__.warning(
@@ -270,7 +304,7 @@ class LHCbSharedRpmSpec(LHCbBaseRpmSpec):
         ''' Return the architecture, always noarch for our packages'''
         return self._arch
 
-    def getRPMName(self, norelease=False):
+    def getRPMName(self, norelease=False, norpmver=False):
         ''' Return the architecture, always noarch for our packages'''
         projname = "_".join([self._project.upper(), self._version])
         projver = ".".join([
@@ -279,6 +313,8 @@ class LHCbSharedRpmSpec(LHCbBaseRpmSpec):
                 _lhcb_patch_version
             ]
         ])
+        if norpmver:
+            return projname
         if norelease:
             return "-".join([projname, projver])
         full = "-".join([projname, projver, str(self._lhcb_release_version)])
@@ -427,7 +463,7 @@ class LHCbExtraSharedRpmSpec(LHCbBaseRpmSpec):
         ''' Return the architecture, always noarch for our packages'''
         return self._arch
 
-    def getRPMName(self, norelease=False):
+    def getRPMName(self, norelease=False, norpmver=False):
         ''' Return the architecture, always noarch for our packages'''
         projname = "_".join([self._project.upper(), self._version, "shared"])
         projver = ".".join([
@@ -436,6 +472,8 @@ class LHCbExtraSharedRpmSpec(LHCbBaseRpmSpec):
                 _lhcb_patch_version
             ]
         ])
+        if norpmver:
+            return projname
         if norelease:
             return "-".join([projname, projver])
         full = "-".join([projname, projver, str(self._lhcb_release_version)])
@@ -588,12 +626,14 @@ class LHCbBinaryRpmSpec(LHCbBaseRpmSpec):
         ''' Return the architecture, always noarch for our packages'''
         return self._arch
 
-    def getRPMName(self, norelease=False):
+    def getRPMName(self, norelease=False, norpmver=False):
         ''' Return the architecture, always noarch for our packages'''
         projname = "_".join([
             self._project.upper(), self._version,
             self._cmtconfig.replace('-', '_')
         ])
+        if norpmver:
+            return projname
         projver = ".".join([
             str(n) for n in [
                 self._lhcb_maj_version, self._lhcb_min_version, self.
@@ -611,6 +651,7 @@ class LHCbBinaryRpmSpec(LHCbBaseRpmSpec):
         Prepare the RPM header
         '''
         header = Template("""
+%define _binaries_in_noarch_packages_terminate_build   0
 %define lhcb_maj_version ${lhcb_maj_version}
 %define lhcb_min_version ${lhcb_min_version}
 %define lhcb_patch_version ${lhcb_patch_version}
@@ -815,9 +856,11 @@ class LHCbGlimpseRpmSpec(LHCbBaseRpmSpec):
         ''' Return the architecture, always noarch for our packages'''
         return self._arch
 
-    def getRPMName(self, norelease=False):
+    def getRPMName(self, norelease=False, norpmver=False):
         ''' Return the architecture, always noarch for our packages'''
         projname = "_".join([self._project.upper(), self._version, "index"])
+        if norpmver:
+            return projname
         projver = ".".join([
             str(n) for n in [
                 self._lhcb_maj_version, self._lhcb_min_version, self.
@@ -993,10 +1036,12 @@ class LHCbDatapkgRpmSpec(LHCbBaseRpmSpec):
         ''' Return the architecture, always noarch for our packages'''
         return self._arch
 
-    def getRPMName(self, norelease=False):
+    def getRPMName(self, norelease=False, norpmver=False):
         ''' Return the architecture, always noarch for our packages'''
         projname = "_".join(
             [self._project.upper(), self._normfulldatapkg, self._version])
+        if norpmver:
+            return projname
         # We keep this package to 1.0.0, but the requirements map the vXrY
         projver = ".".join([str(n) for n in [1, 0, 0]])
         if norelease:
@@ -1192,9 +1237,11 @@ class LHCbLbScriptsRpmSpec(LHCbBaseRpmSpec):
         ''' Return the architecture, always noarch for our packages'''
         return self._arch
 
-    def getRPMName(self, norelease=False):
+    def getRPMName(self, norelease=False, norpmver=False):
         ''' Return the architecture, always noarch for our packages'''
         projname = "_".join([self._project.upper(), self._version])
+        if norpmver:
+            return projname
         projver = ".".join([
             str(n) for n in [
                 self._lhcb_maj_version, self._lhcb_min_version, self.
