@@ -115,7 +115,14 @@ class Script(PlainScript):
             default=None,
             action="store",
             help="Specify the RPM release directory")
-
+        group.add_option(
+            '--checkrelease',
+            dest="checkrelease",
+            default=False,
+            action="store_true",
+            help=
+            "Check the RPM repository to check whether the release number should be incremented"
+        )
         parser.add_option_group(group)
         return parser
 
@@ -153,9 +160,12 @@ class Script(PlainScript):
 
         # Now calling the rpmbuild command
         from subprocess import Popen, PIPE
+        myenv = os.environ.copy()
+        myenv["QA_RPATHS"] = "0x0002"
         process = Popen(["rpmbuild", "-bb", specfilename],
                         stdout=PIPE,
-                        stderr=PIPE)
+                        stderr=PIPE,
+                        env=myenv)
 
         (stdout, stderr) = process.communicate()
         # XXX Careful we should not be caching the stdout and stderr
@@ -231,7 +241,13 @@ class Script(PlainScript):
                              self.options.rpmreldir)
             spec.setRPMReleaseDir(self.options.rpmreldir)
 
+        if self.options.checkrelease:
+            self.log.warning(
+                "Incrementing the release number based on YUM repo")
+            spec.setCheckRelease(self.options.checkrelease)
+
         specfilename = os.path.join(rpmconf.topdir, rpmbuildname + ".spec")
+        self.log.info("Writing spec file to %s" % specfilename)
         with open(specfilename, "w") as outputfile:
             outputfile.write(spec.getSpec())
 
@@ -589,7 +605,7 @@ class Script(PlainScript):
             for info in zipfile.ZipFile(srcArchive, 'r'):
                 if info.filename == manifest:
                     return True
-        except Exception, exc:
+        except Exception as exc:
             self.log.warning('assuming platform dependent project (%s: %s)',
                              exc.__class__.__name__, exc)
             return False
